<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="vi">
<context>
    <name>BitcoinButton</name>
    <message>
        <location filename="../BitcoinButton.qml" line="34"/>
        <source>Bitcoin address</source>
        <translation>Địa chỉ Bitcoin</translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="111"/>
        <source>Copy address</source>
        <translation>Sao chép địa chỉ</translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="116"/>
        <source>Bitcoin address copied to clipboard</source>
        <translation>Địa chỉ Bitcoin đã được sao chép</translation>
    </message>
</context>
<context>
    <name>DonationDialog</name>
    <message>
        <location filename="../DonationDialog.qml" line="8"/>
        <source>Choose a donation method:</source>
        <translation>Chọn cách quyên góp:</translation>
    </message>
</context>
<context>
    <name>FileSelector</name>
    <message>
        <location filename="../FileSelector.qml" line="14"/>
        <source>File Selector</source>
        <translation>Mục chọn File</translation>
    </message>
</context>
<context>
    <name>FlattrButton</name>
    <message>
        <location filename="../FlattrButton.qml" line="25"/>
        <source>Opening &lt;b&gt;Flattr&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation>Mở trang quyên góp &lt;b&gt;Flattr&lt;/b&gt;, &lt;b&gt;xin cám ơn&lt;/b&gt;.</translation>
    </message>
</context>
<context>
    <name>HistoryPage</name>
    <message>
        <location filename="../HistoryPage.qml" line="20"/>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="31"/>
        <location filename="../HistoryPage.qml" line="118"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Do not delete items</source>
        <translation>Đừng xóa các mục</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Delete items</source>
        <translation>Xóa các mục</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="57"/>
        <source>Select items to delete</source>
        <translation>Chọn mục để xóa</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="61"/>
        <location filename="../HistoryPage.qml" line="115"/>
        <source>Erase history</source>
        <translation>Xóa tất cả</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="74"/>
        <source>no entries</source>
        <translation>Chưa có bài nào</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="116"/>
        <source>Do you want to erase the history of all mangas and comic books opened by Mieru?</source>
        <translation>Bạn có chắc là muốn xóa tất cả lưu trữ về tiến bộ đọc trong Mieru?</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="117"/>
        <source>Erase</source>
        <translation>Xóa</translation>
    </message>
</context>
<context>
    <name>InfoPage</name>
    <message>
        <location filename="../InfoPage.qml" line="14"/>
        <source>Info</source>
        <translation>Thông tin</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="18"/>
        <source>Stats</source>
        <translation>Thống kê</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="22"/>
        <source>About</source>
        <translation>Thông tin</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="77"/>
        <source>Properties</source>
        <translation>Thông tin</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="80"/>
        <source>Pages</source>
        <translation>Số trang</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="83"/>
        <source>Path</source>
        <translation>Đường dẫn</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="91"/>
        <source>Online search</source>
        <translation>Tìm trên mạng</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="97"/>
        <source>Opening &lt;b&gt;Google&lt;/b&gt; search</source>
        <translation>Kích hoạt tìm kiếm bằng &lt;b&gt;Google&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="106"/>
        <source>Opening &lt;b&gt;Wikipedia&lt;/b&gt; search</source>
        <translation>Kích hoạt tìm kiếm bằng &lt;b&gt;Wikipedia&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="115"/>
        <source>Opening &lt;b&gt;Manga updates&lt;/b&gt; search</source>
        <translation>Kích hoạt tìm kiếm bằng &lt;b&gt;Manga updates&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="132"/>
        <source>Usage Statistics</source>
        <translation>Thống kê sử dụng</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="162"/>
        <location filename="../InfoPage.qml" line="271"/>
        <source>Reset</source>
        <translation>Thiết lập lại</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="207"/>
        <source>Mieru is a flexible Manga and comic book reader.</source>
        <translation>Mieru là một ứng dụng đọc truyện tranh đa năng.</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="243"/>
        <source>main developer</source>
        <translation>Nhà phát triển chính</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="246"/>
        <source>email</source>
        <translation>email</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="250"/>
        <source>www</source>
        <translation>web</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="255"/>
        <source>discussion</source>
        <translation>thảo luận</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="269"/>
        <source>Reset all usage statistics</source>
        <translation>Thiết lập lại thống kê</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="270"/>
        <source>Do you really want to reset all usage statistics?</source>
        <translation>Bạn có chắc chắn muốn thiết lập lại tất cảthông tin về thống kê sử dụng?</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="272"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../MainView.qml" line="169"/>
        <source>original</source>
        <translation>khởi đầu</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="171"/>
        <source>width</source>
        <translation>chiều ngang</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="173"/>
        <source>height</source>
        <translation>chiều cao</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="175"/>
        <source>screen</source>
        <translation>màn hình</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="177"/>
        <source>orient</source>
        <translation>chế độ xoay</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="184"/>
        <source>most</source>
        <translation>nhiều nhất</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="192"/>
        <source>custom</source>
        <translation>tùy chỉnh</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="250"/>
        <source>Open file</source>
        <translation>Mở file</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="257"/>
        <source>History</source>
        <translation>Lịch sử</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="261"/>
        <source>Info</source>
        <translation>Thông tin</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="265"/>
        <source>Options</source>
        <translation>Tùy chọn</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="272"/>
        <source>Quit</source>
        <translation>Thoát</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="504"/>
        <source>Rotation</source>
        <translation>Xoay</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="524"/>
        <source>No pages loaded</source>
        <translation>Chưa có trang nào</translation>
    </message>
</context>
<context>
    <name>OptionsPage</name>
    <message>
        <location filename="../OptionsPage.qml" line="29"/>
        <source>Page view</source>
        <translation>Cách đọc</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="32"/>
        <source>Rotation</source>
        <translation>Xoay</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="47"/>
        <source>auto</source>
        <translation>tự động</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="55"/>
        <source>portrait</source>
        <translation>dọc</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="63"/>
        <source>landscape</source>
        <translation>ngang</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="71"/>
        <source>Show status bar</source>
        <translation>Hiện thanh chức năng</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="79"/>
        <source>Remember toolbar state</source>
        <translation>Nhớ sự hiển thị của thanh công cụ</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="86"/>
        <source>Fullscreen button opacity</source>
        <translation>Độ trong xuốt của nút khi toàn màn hình</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="112"/>
        <source>Paging options</source>
        <translation>Cách di chuyển</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="115"/>
        <source>Paging mode</source>
        <translation>Phân vùng trên màn hình</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="130"/>
        <source>Whole screen</source>
        <translation>2 phần</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="138"/>
        <source>On edges</source>
        <translation>3 phần</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="148"/>
        <source>Middle click</source>
        <translation>Giữa màn hình</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="158"/>
        <source>Middle doubleclick</source>
        <translation>Nhấp đôi</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="168"/>
        <source>Show paging feedback</source>
        <translation>Hiện phản hồi</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="178"/>
        <source>Page scaling</source>
        <translation>Cách hiển thị trang</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="181"/>
        <source>Page fit mode</source>
        <translation>Hiển thị</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="190"/>
        <source>History</source>
        <translation>Lịch sử</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="193"/>
        <source>history enabled</source>
        <translation>Kích hoạt</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="201"/>
        <source>use when opening files</source>
        <translation>Dùng khi mở file</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="210"/>
        <source>Miscellaneous</source>
        <translation>Linh tinh</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="213"/>
        <source>Manga reading mode</source>
        <translation>Chế độ Manga</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="221"/>
        <source>Show release notes</source>
        <translation>Hiện chú thích</translation>
    </message>
</context>
<context>
    <name>PageFitSelector</name>
    <message>
        <location filename="../PageFitSelector.qml" line="10"/>
        <source>Page fit mode</source>
        <translation>Hiển thị</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="19"/>
        <source>&lt;b&gt;1:1&lt;/b&gt; - original size</source>
        <translation>&lt;b&gt;1:1&lt;/b&gt; - kích thước đầu</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="20"/>
        <source>&lt;b&gt;fit to width&lt;/b&gt;</source>
        <translation>&lt;b&gt;theo chiều ngang&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="21"/>
        <source>&lt;b&gt;fit to height&lt;/b&gt;</source>
        <translation>&lt;b&gt;theo chiều dài&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="22"/>
        <source>&lt;b&gt;fit to screen&lt;/b&gt;</source>
        <translation>&lt;b&gt;nguyên hình&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="23"/>
        <source>&lt;b&gt;custom&lt;/b&gt; - remember scale</source>
        <translation>&lt;b&gt;tùy chỉnh&lt;/b&gt; - ghi nhớ mức độ</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="24"/>
        <source>&lt;b&gt;orientation&lt;/b&gt; specific</source>
        <translation>theo chế độ &lt;b&gt;xoay&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="25"/>
        <source>&lt;b&gt;show the most&lt;/b&gt;</source>
        <translation>&lt;b&gt;lấp đầy màn hình&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="29"/>
        <source>&lt;b&gt;no action&lt;/b&gt;</source>
        <translation>&lt;b&gt;Không thay đổi&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>PayPalButton</name>
    <message>
        <location filename="../PayPalButton.qml" line="24"/>
        <source>Opening &lt;b&gt;PayPal&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation>Mở trang quyên góp &lt;b&gt;PayPal&lt;/b&gt;, &lt;b&gt;xin cám ơn&lt;/b&gt;!</translation>
    </message>
</context>
<context>
    <name>WhatsNewDialog</name>
    <message>
        <location filename="../WhatsNewDialog.qml" line="35"/>
        <source>Opening link</source>
        <translation>Mở liên kết</translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="48"/>
        <source>&lt;b&gt;Do you like Mieru ? Donate !&lt;/b&gt;</source>
        <translation>&lt;b&gt;Thích Mieru? Quyên góp !&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="56"/>
        <source>How to donate ?</source>
        <translation>Quyên góp bằng cách nào ?</translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="67"/>
        <source>Don&apos;t show again</source>
        <translation>Không hiển thị nữa</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="96"/>
        <source>How to turn pages</source>
        <translation>Chuyển trang như thế nào</translation>
    </message>
    <message>
        <location filename="../main.qml" line="97"/>
        <source>Tap the &lt;b&gt;right half&lt;/b&gt; of the screen to go to the &lt;b&gt;next page&lt;/b&gt;.</source>
        <translation>Bấm vào &lt;b&gt;bên phải&lt;/b&gt; màn hình để đến &lt;b&gt;trang tiếp theo&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../main.qml" line="98"/>
        <source>Tap the &lt;b&gt;left half&lt;/b&gt; to go to the &lt;b&gt;previous page&lt;/b&gt;.</source>
        <translation>Bấm vào &lt;b&gt;bên trái&lt;/b&gt; màn hình để về &lt;b&gt;trang trước đó&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../main.qml" line="99"/>
        <source>Don&apos;t show again</source>
        <translation>Không hiển thị nữa</translation>
    </message>
    <message>
        <location filename="../main.qml" line="100"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>
